@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::LiveJournal;
 {
-  $WWW::FetchStory::Fetcher::LiveJournal::VERSION = '0.1820';
+  $WWW::FetchStory::Fetcher::LiveJournal::VERSION = '0.1821';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::LiveJournal - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1820
+version 0.1821
 
 =head1 DESCRIPTION
 
@@ -157,7 +157,7 @@ sub extract_story {
     }
 
     my $story = '';
-    if ($content =~ m#<article class="b-singlepost-body">(.*?)<div class="b-singlepost-tags ljtags">#s)
+    if ($content =~ m#<article class="b-singlepost-body"[^>]*>(.*?)<div class="\s*b-singlepost-tags ljtags\s*"#s)
     {
 	$story = $1;
     }
@@ -250,6 +250,7 @@ sub extract_story {
 	$story =~ s#<a name="cutid."></a>##sg;
         $story =~ s#<a name='cutid.-end'></a>##sg;
         $story =~ s#<center><div class="lj-like">.*</center>##sg;
+        $story =~ s#<a href="http://[A-Za-z_-]+\.livejournal\.com/profile"[^>]*>\s*<img\s*class="i-ljuser-userhead"[^>]*/>\s*</a>##sg;
 
 	$story = $self->tidy_chars($story);
     }
@@ -262,16 +263,10 @@ sub extract_story {
     my $out = <<EOT;
 <h1>$title</h1>
 EOT
-    if ($ljuser)
-    {
-        $out .= <<EOT;
-<p>by $ljuser</p>
-EOT
-    }
     if ($url)
     {
         $out .= <<EOT;
-<p>(from <a href='$url'>here</a>)</p>
+<p>(from <a href='$url'>$url</a>)</p>
 EOT
     }
         $out .= <<EOT;
@@ -311,6 +306,10 @@ sub parse_author {
     {
         $author = $1;
     }
+    elsif ($content =~ m#<b>Creator:\s*</b>\s*<span\s+class="ljuser\s+i-ljuser\s+"\s+lj:user="([-_\w]+)"#)
+    {
+        $author = $1;
+    }
     elsif ($content =~ m#<span class='ljuser ljuser-name_\w+' lj:user='\w+' style='white-space: nowrap;'><a href='http://\w+\.livejournal\.com/profile'><img src='http://l-stat\.livejournal\.com/img/userinfo\.gif' alt='\[info\]' width='17' height='17' style='vertical-align: bottom; border: 0; padding-right: 1px;' /></a><a href='http://\w+\.livejournal\.com/'><b>(.*?)</b></a></span>#)
     {
 	$author = $1;
